summaryrefslogtreecommitdiffstats
path: root/Graphics/GraphicsEngineOpenGL
diff options
context:
space:
mode:
authorassiduous <assiduous@diligentgraphics.com>2021-02-08 19:56:56 +0000
committerassiduous <assiduous@diligentgraphics.com>2021-03-19 00:31:34 +0000
commit9220e5a6b5e8449786acb996204b140305df94fc (patch)
treeb1977c0108e1f6804ff5e9ba7ebe173a8c09f5e1 /Graphics/GraphicsEngineOpenGL
parentReworked PipelineResourceSignatureTest.VulkanDescriptorIndexing to validate r... (diff)
parentUpdated readme (diff)
downloadDiligentCore-9220e5a6b5e8449786acb996204b140305df94fc.tar.gz
DiligentCore-9220e5a6b5e8449786acb996204b140305df94fc.zip
Merged master
Diffstat (limited to 'Graphics/GraphicsEngineOpenGL')
-rw-r--r--Graphics/GraphicsEngineOpenGL/include/DeviceContextGLImpl.hpp5
-rw-r--r--Graphics/GraphicsEngineOpenGL/src/DeviceContextGLImpl.cpp3
2 files changed, 5 insertions, 3 deletions
diff --git a/Graphics/GraphicsEngineOpenGL/src/DeviceContextGLImpl.cpp b/Graphics/GraphicsEngineOpenGL/src/DeviceContextGLImpl.cpp
index d5ca1766..530bc006 100644
--- a/Graphics/GraphicsEngineOpenGL/src/DeviceContextGLImpl.cpp
+++ b/Graphics/GraphicsEngineOpenGL/src/DeviceContextGLImpl.cpp
@@ -1282,7 +1282,8 @@ void DeviceContextGLImpl::FinishCommandList(class ICommandList** ppCommandList)
LOG_ERROR("Deferred contexts are not supported in OpenGL mode");
}
-void DeviceContextGLImpl::ExecuteCommandList(class ICommandList* pCommandList)
+void DeviceContextGLImpl::ExecuteCommandLists(Uint32 NumCommandLists,
+ ICommandList* const* ppCommandLists)
{
LOG_ERROR("Deferred contexts are not supported in OpenGL mode");
}
diff --git a/Graphics/GraphicsEngineOpenGL/include/DeviceContextGLImpl.hpp b/Graphics/GraphicsEngineOpenGL/include/DeviceContextGLImpl.hpp
index fae3cba8..c59a968a 100644
--- a/Graphics/GraphicsEngineOpenGL/include/DeviceContextGLImpl.hpp
+++ b/Graphics/GraphicsEngineOpenGL/include/DeviceContextGLImpl.hpp
@@ -226,8 +226,9 @@ public:
/// Implementation of IDeviceContext::FinishCommandList() in OpenGL backend.
virtual void DILIGENT_CALL_TYPE FinishCommandList(class ICommandList** ppCommandList) override final;
- /// Implementation of IDeviceContext::ExecuteCommandList() in OpenGL backend.
- virtual void DILIGENT_CALL_TYPE ExecuteCommandList(class ICommandList* pCommandList) override final;
+ /// Implementation of IDeviceContext::ExecuteCommandLists() in OpenGL backend.
+ virtual void DILIGENT_CALL_TYPE ExecuteCommandLists(Uint32 NumCommandLists,
+ ICommandList* const* ppCommandLists) override final;
/// Implementation of IDeviceContext::SignalFence() in OpenGL backend.
virtual void DILIGENT_CALL_TYPE SignalFence(IFence* pFence, Uint64 Value) override final;